using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;

namespace Xenoflight.InputServices
{
	public class XboxInputService : InputServiceProvider
	{
		PlayerIndex _index;
		
		public XboxInputService(PlayerIndex player)
		{
			_index = player;
		}

		public bool IsKeyDown(InputControls control)
		{
			GamePadState gps = GamePad.GetState(_index);
			
			if (!gps.IsConnected) return false;

			switch (control)
			{
				case InputControls.Up:
					return gps.ThumbSticks.Right.Y < 0 || gps.ThumbSticks.Left.Y < 0 || gps.DPad.Up == ButtonState.Pressed;
				case InputControls.Down:
					return gps.ThumbSticks.Right.Y > 0 || gps.ThumbSticks.Left.Y > 0 || gps.DPad.Down == ButtonState.Pressed;
				case InputControls.Left:
					return gps.ThumbSticks.Left.X < 0 || gps.ThumbSticks.Right.X < 0 || gps.DPad.Left == ButtonState.Pressed;
				case InputControls.Right:
					return gps.ThumbSticks.Left.X > 0 || gps.ThumbSticks.Right.X > 0 || gps.DPad.Right == ButtonState.Pressed;
				case InputControls.Menu:
					return gps.Buttons.Start == ButtonState.Pressed;
				case InputControls.Select:
					return gps.Buttons.A == ButtonState.Pressed;
				case InputControls.Fire1:
					return gps.Triggers.Right != 0 || gps.Buttons.RightShoulder == ButtonState.Pressed || gps.Buttons.A == ButtonState.Pressed || gps.Buttons.X == ButtonState.Pressed;
				case InputControls.Fire2:
					return gps.Triggers.Left != 0 || gps.Buttons.LeftShoulder == ButtonState.Pressed || gps.Buttons.B == ButtonState.Pressed || gps.Buttons.Y == ButtonState.Pressed;
			}
			return false;
		}

		public bool IsKeyUp(InputControls control)
		{
			return !IsKeyDown(control);
		}
	}
}
