#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace Xenoflight
{
    abstract class AnimatedSprite : SpaceObject
    {
        int _fps;
        int frame = 0;
        Texture2D[] _frames;
        double elapsedSeconds;

        public AnimatedSprite(GameState gameState)
            : base(gameState)
        {
        }

        public void SetFrames(Texture2D[] frames)
        {
            _frames = frames;
        }

        public override void Update(GameTime time)
        {
            elapsedSeconds += time.ElapsedGameTime.TotalSeconds * _gameState._timeScale;
            int frames = (int)(elapsedSeconds * _fps);
            frame += frames;
            elapsedSeconds -= (double)frames * (1 / (double)_fps);
            while (frame >= _frames.Length) frame -= _frames.Length;
        }

        public int FPS
        {
            get
            {
                return _fps;
            }
            set
            {
                _fps = value;
            }
        }

        public override Texture2D Texture
        {
            get
            {
                return _frames[frame];
            }
            set
            {
                throw new NotImplementedException();
            }
        }

    }
}
