#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace Xenoflight
{
	class BodyDebugger : GameComponent
	{
		GameState _gameState;
		string _facility;
		Physics2DDotNet.Body _body;

		public BodyDebugger(GameState gameState, Physics2DDotNet.Body body, string facility)
			: base(gameState._game)
		{
			_gameState = gameState;
			_facility = facility;
			_body = body;

			body.Added += new EventHandler(body_Added);
			body.Collided += new EventHandler<Physics2DDotNet.CollisionEventArgs>(body_Collided);
			body.LifetimeChanged += new EventHandler(body_LifetimeChanged);
			body.Pending += new EventHandler(body_Pending);
			body.PositionChanged += new EventHandler(body_PositionChanged);
			body.Removed += new EventHandler<Physics2DDotNet.RemovedEventArgs>(body_Removed);
			body.ShapeChanged += new EventHandler(body_ShapeChanged);
			body.Updated += new EventHandler<Physics2DDotNet.UpdatedEventArgs>(body_Updated);
		}

		public override void Update(GameTime gameTime)
		{
			Log.log(_facility, "Location: " + _body.State.Position.Linear.X + ", " + _body.State.Position.Linear.Y);
			Log.log(_facility, "Velocity: " + _body.State.Velocity.Linear.X + ", " + _body.State.Velocity.Linear.Y);
			base.Update(gameTime);
		}

		void body_Updated(object sender, Physics2DDotNet.UpdatedEventArgs e)
		{
			Log.log(_facility, "Updated (DT: " + e.DT + ")");
		}

		void body_ShapeChanged(object sender, EventArgs e)
		{
			Log.log(_facility, "ShapeChanged");
		}

		void body_Removed(object sender, Physics2DDotNet.RemovedEventArgs e)
		{
			Log.log(_facility, "Removed (WasPending: " + e.WasPending + ")");
		}

		void body_PositionChanged(object sender, EventArgs e)
		{
			Log.log(_facility, "PositionChanged");
			Log.log(_facility, "New location: " + _body.State.Position.Linear.X + ", " + _body.State.Position.Linear.Y);
		}

		void body_Pending(object sender, EventArgs e)
		{
			Log.log(_facility, "Pending");
		}

		void body_LifetimeChanged(object sender, EventArgs e)
		{
			Log.log(_facility, "LifetimeChanged");
		}

		void body_Collided(object sender, Physics2DDotNet.CollisionEventArgs e)
		{
			Log.log(_facility, "Collided");
		}

		void body_Added(object sender, EventArgs e)
		{
			Log.log(_facility, "Added");
		}
	}
}
