#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
using System.IO;
#endregion

namespace Xenoflight
{
    class Log : GameComponent
    {
        static Dictionary<string, StreamWriter> _facilities;
        static GameState _gameState;

        public Log(GameState gameState, Dictionary<string, string> facilities)
            : base(gameState._game)
        {
#if DEBUG
            _gameState = gameState;
            _facilities = new Dictionary<string, StreamWriter>();
			foreach (KeyValuePair<string, string> kvp in facilities)
			{
				StreamWriter SW = new StreamWriter("logs/" + kvp.Value);
				SW.AutoFlush = true;
				_facilities.Add(kvp.Key, SW);
			}
#endif
        }

        public static void log(string facility, string message)
        {
#if DEBUG
			string part = "";
            do
            {
				if (_facilities.ContainsKey(facility))
					_facilities[facility].WriteLine("[" + DateTime.Now + "] " + ((part != "") ? "{" + part + "} " : "") + message);
				else
					System.Diagnostics.Debug.Assert(_facilities.ContainsKey(facility));
				if (facility.Contains("."))
				{
					part = facility.Substring(facility.LastIndexOf('.')) + part;
					facility = facility.Substring(0, facility.LastIndexOf('.'));
				}
				else
					facility = "";
            } while (facility.Length > 0);
#endif
        }

        public override void Update(GameTime gameTime)
        {
#if DEBUG
            log("xeno.engine", "Update(" + gameTime.ElapsedGameTime.TotalSeconds + "*" + _gameState._timeScale + "=" + (gameTime.ElapsedGameTime.TotalSeconds * _gameState._timeScale) + ")");
            base.Update(gameTime);
#endif
        }
    }
}
