#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace Xenoflight
{
    class Map : DrawableGameComponent
    {
        GameState _gameState;
        Tile[,] _tiles;
        int _width, _height;
        public TileManager _tileManager;
        GraphicsDevice draw;
        SpriteBatch _spriteBatch;
        string _tileFile;

        public Map(GameState gameState, int width, int height, string tileFile)
            : base(gameState._game)
        {
            _width = width;
            _height = height;
            _tiles = new Tile[width, height];
            _tileManager = null;
            _gameState = gameState;
            draw = _gameState._graphics.GraphicsDevice;
            _spriteBatch = new SpriteBatch(draw);
            _tileFile = tileFile;
        }

        public void LinkTiles()
        {
            for (int y = 0; y < _height; y++)
                for (int x = 0; x < _width; x++)
                    _tiles[x, y].texture = _tileManager[_tiles[x, y].graphic];
        }

        public void UnlinkTiles()
        {
            for (int y = 0; y < _height; y++)
                for (int x = 0; x < _width; x++)
                    _tiles[x, y].texture = null;
        }

        public void GenerateCollisions()
        {
			for (int y = 0; y < _height; y++)
				for (int x = 0; x < _width; x++)
					if (_tiles[x, y].solid)
					{
						_gameState._physicsEngine.AddBody(new Physics2DDotNet.Body(
							new Physics2DDotNet.PhysicsState(new Physics2DDotNet.Math2D.ALVector2D(0, x + 0.5f, y + 0.5f)),
							new Physics2DDotNet.Polygon(Physics2DDotNet.Polygon.CreateRectangle(0.5f, 0.5f), Constants.physicsGridSize),
							new Physics2DDotNet.MassInfo(float.PositiveInfinity, float.PositiveInfinity),
							_gameState._physicsCoefficients.Duplicate(),
							new Physics2DDotNet.Lifespan()
						));
						Physics2DDotNet.Body body = new Physics2DDotNet.Body(new Physics2DDotNet.PhysicsState(), new Physics2DDotNet.Polygon(Physics2DDotNet.Polygon.CreateRectangle(1, 1), Constants.physicsGridSize), float.PositiveInfinity, _gameState._physicsCoefficients.Duplicate(), new Physics2DDotNet.Lifespan());
						body.State.Position = new Physics2DDotNet.Math2D.ALVector2D(0, x + 0.5f, y + 0.5f);
						_gameState._physicsEngine.AddBody(body);
					}
        }

        public override void Initialize()
        {
			GenerateCollisions();
			_tileManager = new TileManager(_gameState._graphics, _tileFile);
			LinkTiles();
            base.Initialize();            
        }

		~Map()
		{
			_tileManager.Dispose();
			UnlinkTiles();
		}

        public override void Draw(GameTime gameTime)
        {
            draw.Clear(Color.Black);

			int xShift = 0, yShift = 0;
			xShift = -(int)(_gameState._drawLocation.X % _gameState._tileWidth);
			yShift = -(int)(_gameState._drawLocation.Y % _gameState._tileHeight);
			int startX = (int)(_gameState._drawLocation.X / _gameState._tileWidth);
			int startY = (int)(_gameState._drawLocation.Y / _gameState._tileHeight);

			int endX = draw.Viewport.Width / _gameState._tileWidth + startX + 1;
			int endY = draw.Viewport.Height / _gameState._tileHeight + startY + 1;

            int xLoc = xShift, yLoc = yShift;

            _spriteBatch.Begin();
            for (int y = startY; y < endY; y++)
            {
                for (int x = startX; x < endX; x++)
                {
                    if (x >= 0 && x < _gameState._map.Width && y >= 0 && y < _gameState._map.Height && _tiles[x, y].graphic != 0)
                        _spriteBatch.Draw(_tiles[x, y].texture, new Vector2(xLoc, yLoc), Color.White);
                    xLoc += _gameState._tileWidth;
                }
                xLoc = xShift;
                yLoc += _gameState._tileHeight;
            }
            _spriteBatch.End();

            base.Draw(gameTime);
        }

        public override void Update(GameTime gameTime)
        {

            base.Update(gameTime);
        }

        public int Width
        {
            get
            {
                return _width;
            }
        }

        public int Height
        {
            get
            {
                return _height;
            }
        }

        public Tile this[int x, int y]
        {
            get
            {
                return _tiles[x, y];
            }
            set
            {
                _tiles[x, y] = value;
            }
        }

        public static Map FromFile(GameState gameState, string filename)
        {
            filename = Paths.Maps + "\\" + filename;
            string ext = filename.Substring(filename.LastIndexOf('.')+1);
            switch (ext)
            {
                case "map":
                    return new MapTextLoader().Load(gameState, filename);
                default:
                    break;
            }
            return null;
        }
    }
}
