#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;

#endregion

namespace Xenoflight
{
    class Player : GameComponent
    {
        GameState _gameState;
        Ship _ship;
        InputServices.InputServiceProvider _input;

        public Player(GameState gameState, Ship ship)
            : base(gameState._game)
        {
			Log.log("xeno.player", "Initializing player on ship " + ship.ToString());
            _gameState = gameState;
            _ship = ship;
			Log.log("xeno.player.input", "Binding to input service...");
            _input = (InputServices.InputServiceProvider)_gameState._game.Services.GetService(typeof(InputServices.InputServiceProvider));
			Log.log("xeno.player.input", "Found " + _input.ToString());
			_ship.Body.Removed += new EventHandler<Physics2DDotNet.RemovedEventArgs>(Body_Removed);
        }

		void Body_Removed(object sender, Physics2DDotNet.RemovedEventArgs e)
		{
			// TODO: Handle death better.
			//_gameState._game.Exit();
		}

        public Player(GameState gameState, Ship ship, InputServices.InputServiceProvider input)
            : base(gameState._game)
        {
			Log.log("xeno.player", "Initializing player on ship " + ship.ToString());
            _gameState = gameState;
            _ship = ship;
			Log.log("xeno.player.input", "Using passed in input service " + input.ToString());
            _input = input;
        }

        public override void Update(GameTime gameTime)
        {
			Log.log("xeno.player", "Update(" + gameTime.ElapsedGameTime.TotalSeconds + ")");

			float seconds = (float)gameTime.ElapsedGameTime.TotalSeconds * _gameState._timeScale;

			float autolevel = Constants.shipAutoLevel * seconds;
			if (_ship.Body.State.Velocity.Linear.X < autolevel && _ship.Body.State.Velocity.Linear.X > -autolevel)
				_ship.Body.State.Velocity.Linear.X = 0;
			if (_ship.Body.State.Velocity.Linear.Y < autolevel && _ship.Body.State.Velocity.Linear.Y > -autolevel)
				_ship.Body.State.Velocity.Linear.Y = 0;

            if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Up))
            {
				Log.log("xeno.player.input", "Up");
				if (_ship.Body.State.Velocity.Linear.Y > -_ship.Up.Speed)
					_ship.Body.State.Velocity.Linear.Y -= _ship.Up.Acceleration * seconds;
            }
            else if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Down))
            {
				Log.log("xeno.player.input", "Down");
				if (_ship.Body.State.Velocity.Linear.Y < _ship.Down.Speed)
					_ship.Body.State.Velocity.Linear.Y += _ship.Down.Acceleration * seconds;
            }
            if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Left))
            {
				Log.log("xeno.player.input", "Left");
				if (_ship.Body.State.Velocity.Linear.X > -_ship.Backwards.Speed)
					_ship.Body.State.Velocity.Linear.X -= _ship.Backwards.Acceleration * seconds;
            }
			else if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Right))
			{
				Log.log("xeno.player.input", "Right");
				if (_ship.Body.State.Velocity.Linear.X < _ship.Forwards.Speed)
					_ship.Body.State.Velocity.Linear.X += _ship.Forwards.Acceleration * seconds;
			}

            if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Select))
            {
				Log.log("xeno.player.input", "Select");
            }
            if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Menu))
            {
				Log.log("xeno.player.input", "Menu");
                _gameState._game.Exit();
            }

            if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Fire1))
            {
				Log.log("xeno.player.input", "Fire1");
            }
            if (_input.IsKeyDown(global::Xenoflight.InputServices.InputControls.Fire2))
            {
				Log.log("xeno.player.input", "Fire2");
            }

			_gameState._drawLocation.X = (_ship.Location.X * _gameState._tileWidth) - (_gameState._graphics.GraphicsDevice.Viewport.Width / 3f);
			if (_gameState._drawLocation.X < 0) { _gameState._drawLocation.X = 0; }
			_gameState._drawLocation.Y = (_ship.Location.Y * _gameState._tileHeight) - (_gameState._graphics.GraphicsDevice.Viewport.Height / 2f);
			if (_gameState._drawLocation.Y < 0) { _gameState._drawLocation.Y = 0; }

            base.Update(gameTime);
        }
    }
}
