#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace Xenoflight
{
    abstract class SpaceObject
    {
        protected GameState _gameState;
        protected Texture2D _texture;
        protected Physics2DDotNet.Body _body;
		protected Color _tint = Color.White;

        public SpaceObject(GameState gameState)
        {
            _gameState = gameState;
        }

		public virtual Color Tint
		{
			get
			{
				return _tint;
			}
			set
			{
				_tint = value;
			}
		}

        public Physics2DDotNet.Body Body
        {
            get
            {
                return _body;
            }
            set
            {
                _body = value;
            }
        }

        public Physics2DDotNet.PhysicsState State
        {
            get
            {
				return _body.State;
            }
        }

        public abstract Physics2DDotNet.Shape CollisionShape { get; }
        
		public Vector2 Location
        {
            get
            {
                return new Vector2(_body.State.Position.Linear.X, _body.State.Position.Linear.Y);
            }
            set
            {
                _body.State.Position.Linear.X = value.X;
                _body.State.Position.Linear.Y = value.Y;
            }
        }
        public Vector2 Velocity
        {
            get
            {
                return new Vector2(_body.State.Velocity.Linear.X, _body.State.Velocity.Linear.Y);
            }
            set
            {
                _body.ApplyForce(new AdvanceMath.Vector2D(value.X, value.Y));
            }
        }
        public abstract float Mass { get; }

        public virtual Texture2D Texture
        {
            get
            {
                return _texture;
            }
            set
            {
                _texture = value;
            }
        }

        public virtual void Die()
        {
            _gameState._spriteManager.Remove(this);
        }

        public virtual void Update(GameTime gameTime)
        {
        }

		public virtual void Collided(SpaceObject so)
		{
		}
    }
}
