#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace Xenoflight
{
    class TileManager
    {
        Texture2D[] _textures;

        public int Width
        {
            get
            {
                return 32;
            }
        }

        public int Height
        {
            get
            {
                return 32;
            }
        }

        public TileManager(GraphicsDeviceManager graphics, string textureFilename)
        {
            textureFilename = Paths.Tiles + "\\" + textureFilename + ".tileset";
            Load(graphics, textureFilename);
        }

        public void Dispose()
        {
            foreach (Texture2D texture in _textures)
            {
                texture.Dispose();
            }
        }

        public void Load(GraphicsDeviceManager graphics, string filename)
        {
            Dictionary<int, Texture2D> textures = new Dictionary<int, Texture2D>();
            System.IO.StreamReader sr = new System.IO.StreamReader(filename);
            string basepath = "/", baseext = "";
            while (!sr.EndOfStream)
            {
                string line = sr.ReadLine();
                if (line == "" || line.Substring(0, 1) == "#")
                    continue;
                string[] parts = line.Split(' ');
                switch (parts[0])
                {
                    case "base":
                        basepath = parts[1];
                        break;
                    case "ext":
                        baseext = "." + parts[1];
                        break;
                    default:
                        textures.Add(int.Parse(parts[0]), Texture2D.FromFile(graphics.GraphicsDevice, Paths.Tiles + basepath + parts[1] + baseext));
                        break;
                }
                int highest = 0;
                foreach (int key in textures.Keys)
                    if (key > highest)
                        highest = key;
                _textures = new Texture2D[highest+1];
                foreach (KeyValuePair<int, Texture2D> pair in textures)
                    _textures[pair.Key] = pair.Value;
            }
        }

        public Texture2D this[int index]
        {
            get
            {
                return _textures[index];
            }
        }
    }
}
